#####Data to compute latent Big Five domains are not publicly available#####
#####The dataset created with this script can be downloaded at http://madata.bib.uni-mannheim.de/333/8/B5FacetsRelig_Study2_data_latent-B5-domains.sav#####

#install packages
install.packages(c("foreign","psych","lavaan"))

#load packages
library(foreign, pos=4)
library(psych)
library(lavaan)

#read data
dat <- read.spss("study2_final_sample.sav", use.value.labels=FALSE, max.value.labels=inf, to.data.frame=TRUE)
cnt <-(unique(dat$cnt_now))

#set working directory to the folder to which the output file should be saved (e.g., "C:/B5FacetsRelig")
setwd("C:/B5FacetsRelig")

#create output file
var.lin <- paste("cnt", "orelig", "oagr", "ocns", "oext", "oneu", "oopn", sep=",", collapse = NULL)
write(var.lin, file = "B5FacetsRelig_Study2_data_latent-B5-domains.txt", append = TRUE)


#latent Big Five domains

for (i in 1:length(cnt)){ 
  temp <- dat[dat$cnt_now==cnt[i],]
  
  a <- '
  agr =~ oagr01r + oagr02 + oagr03r + oagr04 + oagr05 + oagr06r + oagr07 + oagr08r + oagr09
  '
  
  c <- '
  cns =~ ocns01 + ocns02r + ocns03 + ocns04r + ocns05r + ocns06 + ocns07 + ocns08 + ocns09r
  '
  
  e <- '
  ext =~ oext01 + oext02r + oext03 + oext04 + oext05r + oext06 + oext07r + oext08
  '
  
  n <- '
  neu =~ oneu01 + oneu02r + oneu03 + oneu04 + oneu05r + oneu06 + oneu07r + oneu08
  '
  
  o <- '
  opn =~ oopn01 + oopn02 + oopn03 + oopn04 + oopn05 + oopn06 + oopn07r + oopn08 + oopn09r + oopn10
  '
 
  orelig <- temp$orelig
  
  fit.a <- sem(a, missing = "FIML", data = temp)
  fscores.a <- lavPredict(fit.a) 
  agr <- fscores.a[,1]
  
  fit.c <- sem(c, missing = "FIML", data = temp)
  fscores.c <- lavPredict(fit.c) 
  cns <- fscores.c[,1]
  
  fit.e <- sem(e, missing = "FIML", data = temp)
  fscores.e <- lavPredict(fit.e) 
  ext <- fscores.e[,1]
  
  fit.n <- sem(n, missing = "FIML", data = temp)
  fscores.n <- lavPredict(fit.n) 
  neu <- fscores.n[,1]
  
  fit.o <- sem(o, missing = "FIML", data = temp)
  fscores.o <- lavPredict(fit.o) 
  opn <- fscores.o[,1]


  # output
  out.lin <- paste(cnt[i], 
                   round(orelig, digits=4), round(agr, digits=4), round(cns, digits=4), round(ext, digits=4), round(neu, digits=4),
                   round(opn, digits=4), sep = ",", collapse = NULL)
 
  write(out.lin, file = "B5FacetsRelig_Study2_data_latent-B5-domains.txt", append = TRUE)
}


