#install packages
install.packages(c("foreign","psych","lavaan"))

#load packages
library(foreign, pos=4)
library(psych)
library(lavaan)

#read data
dat <- read.spss("http://madata.bib.uni-mannheim.de/333/1/B5FacetsRelig_Study2_data.sav", use.value.labels=FALSE, max.value.labels=inf, to.data.frame=TRUE)
cnt <-(unique(dat$cnt_now))

#set working directory to the folder to which the output file should be saved (e.g., "C:/B5FacetsRelig")
setwd("C:/B5FacetsRelig")

#create output file
var.lin <- paste("cnt", "orelig", "oalt", "ocom", "oord", "odis", "oass", 
                 "oact", "oaes", "oide", "oanx", "odep", sep=",", collapse = NULL)
write(var.lin, file = "B5FacetsRelig_Study2_data_latent-B5-facets.txt", append = TRUE)


#latent Big Five facets

for (i in 1:length(cnt)){ 
  temp <- dat[dat$cnt_now==cnt[i],]
  
  m.alt <- '
  alt =~ oagr02 + oagr05 + oagr06r + oagr07
  '
  
  m.com <- '
  comp =~ oagr01r + oagr03r + oagr04
  '
  
  m.ord <- '
  orde =~ a*ocns02r + a*ocns04r
  orde ~~ 1*orde
  '
  
  m.dis <- '
  disc =~ ocns03 + ocns05r + ocns06 + ocns08 + ocns09r
  '
  
  m.ass  <- '
  asse =~ oext01 + oext02r + oext05r + oext06 + oext07r  
  '
  
  m.act <- '
  acti =~ b*oext03 + b*oext04
  acti ~~ 1*acti
  '
  
  m.aes <- '
  aest =~ oopn06 + oopn09r + oopn10
  '
  
  m.ide <- '
  idea =~ oopn02 + oopn03 + oopn05 + oopn07r + oopn08
  '
  
  m.anx <- '
  anxi  =~ oneu02r + oneu04 + oneu07r + oneu08
  '
  
  m.dep <- '
  depr =~ c*oneu01 + c*oneu06
  depr ~~ 1*depr
  '
 
 #save religiosity
  orelig <- temp$orelig
  
#save altruisim  
  fit.alt <- sem(m.alt, missing = "FIML", data = temp)
  fscores.alt <- lavPredict(fit.alt) 
  alt <- fscores.alt[,1]
  
#save compliance
  fit.com <- sem(m.com, missing = "FIML", data = temp)
  fscores.com <- lavPredict(fit.com) 
  com <- fscores.com[,1]

#save order 
  fit.ord <- sem(m.ord, missing = "FIML", data = temp)
  fscores.ord <- lavPredict(fit.ord) 
  ord <- fscores.ord[,1]
  
#save self-disc
  fit.dis <- sem(m.dis, missing = "FIML", data = temp)
  fscores.dis <- lavPredict(fit.dis) 
  dis <- fscores.dis[,1]

# save assertiveness
  fit.ass <- sem(m.ass, missing = "FIML", data = temp)
  fscores.ass <- lavPredict(fit.ass) 
  ass <- fscores.ass[,1]
  
  #save activity
  fit.act <- sem(m.act, missing = "FIML", data = temp)
  fscores.act <- lavPredict(fit.act) 
  act <- fscores.act[,1]
  
  #save aestetics
  fit.aes <- sem(m.aes, missing = "FIML", data = temp)
  fscores.aes <- lavPredict(fit.aes) 
  aes <- fscores.aes[,1]
  
  #save ideas 
  fit.ide <- sem(m.ide, missing = "FIML", data = temp)
  fscores.ide <- lavPredict(fit.ide) 
  ide <- fscores.ide[,1]
  
  #save anxiety
  fit.anx <- sem(m.anx, missing = "FIML", data = temp)
  fscores.anx <- lavPredict(fit.anx) 
  anx <- fscores.anx[,1]
  
  # save depression
  fit.dep <- sem(m.dep, missing = "FIML", data = temp)
  fscores.dep <- lavPredict(fit.dep) 
  dep <- fscores.dep[,1]
  
  # output 
  out.lin <- paste(cnt[i], 
                   round(orelig, digits=4), round(alt, digits=4), round(com, digits=4), round(ord, digits=4), round(dis, digits=4),
                   round(ass, digits=4), round(act, digits=4), round(aes, digits=4), round(ide, digits=4), round(anx, digits=4),
                   round(dep, digits=4), sep = ",", collapse = NULL)
 
  write(out.lin, file = "B5FacetsRelig_Study2_data_latent-B5-facets.txt", append = TRUE)

}


