#install packages
install.packages(c("foreign","psych","lavaan"))

#load packages
library(foreign, pos=4)
library(psych)
library(lavaan)

#read data
dat <- read.spss("http://madata.bib.uni-mannheim.de/333/1/B5FacetsRelig_Study2_data.sav", use.value.labels=FALSE, max.value.labels=inf, to.data.frame=TRUE)

#set working directory to the folder to which the output file should be saved (e.g., "C:/B5FacetsRelig")
setwd("C:/B5FacetsRelig")

#create output file
out.lin <- paste("trait", "model", "cfi", "rmsea", "srmr", sep = ",", collapse = NULL)
write(out.lin, file = "mi_study2.txt")


#ALTRUISM
#configural model
alt.mod <- paste("
                  alt.lat =~ oagr02 + oagr05 + oagr06r + oagr07
                  ")

alt.config.fit <- sem(alt.mod, data = dat, group = "cnt_now")
alt.config.cfi.sav <- fitMeasures(alt.config.fit, "cfi")
alt.config.rmsea.sav <- fitMeasures(alt.config.fit, "rmsea")
alt.config.srmr.sav <- fitMeasures(alt.config.fit, "srmr")

out.lin <- paste ("altr", "config", round(alt.config.cfi.sav, digits = 3), round(alt.config.rmsea.sav, digits = 3), round(alt.config.srmr.sav, digits = 3), sep = ",", collapse = NULL)
write(out.lin, file = "mi_study2.txt", append = TRUE)


#metric model
alt.metric.fit <- sem(alt.mod, data = dat, group = "cnt_now", group.equal = c("loadings"))
alt.metric.cfi.sav <- fitMeasures(alt.metric.fit, "cfi")
alt.metric.rmsea.sav <- fitMeasures(alt.metric.fit, "rmsea")
alt.metric.srmr.sav <- fitMeasures(alt.metric.fit, "srmr")

out.lin <- paste ("altr", "metric", round(alt.metric.cfi.sav, digits = 3), round(alt.metric.rmsea.sav, digits = 3), round(alt.metric.srmr.sav, digits = 3), sep = ",", collapse = NULL)
write(out.lin, file = "mi_study2.txt", append = TRUE)


#COMPLIANCE
#configural model
comp.mod <- paste("
                 comp.lat =~ oagr01r + oagr03r + oagr04
                 ")

comp.config.fit <- sem(comp.mod, data = dat, group = "cnt_now")
comp.config.cfi.sav <- fitMeasures(comp.config.fit, "cfi")
comp.config.rmsea.sav <- fitMeasures(comp.config.fit, "rmsea")
comp.config.srmr.sav <- fitMeasures(comp.config.fit, "srmr")

out.lin <- paste ("comp", "config", round(comp.config.cfi.sav, digits = 3), round(comp.config.rmsea.sav, digits = 3), round(comp.config.srmr.sav, digits = 3), sep = ",", collapse = NULL)
write(out.lin, file = "mi_study2.txt", append = TRUE)


#metric model
comp.metric.fit <- sem(comp.mod, data = dat, group = "cnt_now", group.equal = c("loadings"))
comp.metric.cfi.sav <- fitMeasures(comp.metric.fit, "cfi")
comp.metric.rmsea.sav <- fitMeasures(comp.metric.fit, "rmsea")
comp.metric.srmr.sav <- fitMeasures(comp.metric.fit, "srmr")

out.lin <- paste ("comp", "metric", round(comp.metric.cfi.sav, digits = 3), round(comp.metric.rmsea.sav, digits = 3), round(comp.metric.srmr.sav, digits = 3), sep = ",", collapse = NULL)
write(out.lin, file = "mi_study2.txt", append = TRUE)


#ORDER
#configural model
orde.mod <- paste("
                  orde.lat =~ a*ocns02r + a*ocns04r
                  orde.lat ~~ 1*orde.lat
                  ")

orde.config.fit <- sem(orde.mod, data = dat, group = "cnt_now")
orde.config.cfi.sav <- fitMeasures(orde.config.fit, "cfi")
orde.config.rmsea.sav <- fitMeasures(orde.config.fit, "rmsea")
orde.config.srmr.sav <- fitMeasures(orde.config.fit, "srmr")

out.lin <- paste ("orde", "config", round(orde.config.cfi.sav, digits = 3), round(orde.config.rmsea.sav, digits = 3), round(orde.config.srmr.sav, digits = 3), sep = ",", collapse = NULL)
write(out.lin, file = "mi_study2.txt", append = TRUE)


#metric model
orde.metric.fit <- sem(orde.mod, data = dat, group = "cnt_now", group.equal = c("loadings"))
orde.metric.cfi.sav <- fitMeasures(orde.metric.fit, "cfi")
orde.metric.rmsea.sav <- fitMeasures(orde.metric.fit, "rmsea")
orde.metric.srmr.sav <- fitMeasures(orde.metric.fit, "srmr")

out.lin <- paste ("orde", "metric", round(orde.metric.cfi.sav, digits = 3), round(orde.metric.rmsea.sav, digits = 3), round(orde.metric.srmr.sav, digits = 3), sep = ",", collapse = NULL)
write(out.lin, file = "mi_study2.txt", append = TRUE)


#SELF DISCIPLINE
#configural model
disc.mod <- paste("
                  disc.lat =~ ocns03 + ocns05r + ocns06 + ocns08 + ocns09r
                  meth.fac =~ 1*ocns05r + 1*ocns09r 
                  disc.lat ~~ 0*meth.fac
                  ")

disc.config.fit <- sem(disc.mod, data = dat, group = "cnt_now")
disc.config.cfi.sav <- fitMeasures(disc.config.fit, "cfi")
disc.config.rmsea.sav <- fitMeasures(disc.config.fit, "rmsea")
disc.config.srmr.sav <- fitMeasures(disc.config.fit, "srmr")

out.lin <- paste ("disc", "config", round(disc.config.cfi.sav, digits = 3), round(disc.config.rmsea.sav, digits = 3), round(disc.config.srmr.sav, digits = 3), sep = ",", collapse = NULL)
write(out.lin, file = "mi_study2.txt", append = TRUE)


#metric model
disc.metric.fit <- sem(disc.mod, data = dat, group = "cnt_now", group.equal = c("loadings"))
disc.metric.cfi.sav <- fitMeasures(disc.metric.fit, "cfi")
disc.metric.rmsea.sav <- fitMeasures(disc.metric.fit, "rmsea")
disc.metric.srmr.sav <- fitMeasures(disc.metric.fit, "srmr")

out.lin <- paste ("disc", "metric", round(disc.metric.cfi.sav, digits = 3), round(disc.metric.rmsea.sav, digits = 3), round(disc.metric.srmr.sav, digits = 3), sep = ",", collapse = NULL)
write(out.lin, file = "mi_study2.txt", append = TRUE)


#ASSERTIVENESS
#configural model
asse.mod <- paste("
                  asse.lat =~ oext01 + oext02r + oext05r + oext06 + oext07r
                  meth.fac =~ 1*oext02r + 1*oext05r + 1*oext07r
                  asse.lat ~~ 0*meth.fac
                  ")

asse.config.fit <- sem(asse.mod, data = dat, group = "cnt_now")
asse.config.cfi.sav <- fitMeasures(asse.config.fit, "cfi")
asse.config.rmsea.sav <- fitMeasures(asse.config.fit, "rmsea")
asse.config.srmr.sav <- fitMeasures(asse.config.fit, "srmr")

out.lin <- paste ("asse", "config", round(asse.config.cfi.sav, digits = 3), round(asse.config.rmsea.sav, digits = 3), round(asse.config.srmr.sav, digits = 3), sep = ",", collapse = NULL)
write(out.lin, file = "mi_study2.txt", append = TRUE)


#metric model
asse.metric.fit <- sem(asse.mod, data = dat, group = "cnt_now", group.equal = c("loadings"))
asse.metric.cfi.sav <- fitMeasures(asse.metric.fit, "cfi")
asse.metric.rmsea.sav <- fitMeasures(asse.metric.fit, "rmsea")
asse.metric.srmr.sav <- fitMeasures(asse.metric.fit, "srmr")

out.lin <- paste ("asse", "metric", round(asse.metric.cfi.sav, digits = 3), round(asse.metric.rmsea.sav, digits = 3), round(asse.metric.srmr.sav, digits = 3), sep = ",", collapse = NULL)
write(out.lin, file = "mi_study2.txt", append = TRUE)


#ACTIVITY
#configural model
acti.mod <- paste("
                  acti.lat =~ a*oext03 + a*oext04
                  acti.lat ~~ 1*acti.lat
                  ")

acti.config.fit <- sem(acti.mod, data = dat, group = "cnt_now")
acti.config.cfi.sav <- fitMeasures(acti.config.fit, "cfi")
acti.config.rmsea.sav <- fitMeasures(acti.config.fit, "rmsea")
acti.config.srmr.sav <- fitMeasures(acti.config.fit, "srmr")

out.lin <- paste ("acti", "config", round(acti.config.cfi.sav, digits = 3), round(acti.config.rmsea.sav, digits = 3), round(acti.config.srmr.sav, digits = 3), sep = ",", collapse = NULL)
write(out.lin, file = "mi_study2.txt", append = TRUE)


#metric model
acti.metric.fit <- sem(acti.mod, data = dat, group = "cnt_now", group.equal = c("loadings"))
acti.metric.cfi.sav <- fitMeasures(acti.metric.fit, "cfi")
acti.metric.rmsea.sav <- fitMeasures(acti.metric.fit, "rmsea")
acti.metric.srmr.sav <- fitMeasures(acti.metric.fit, "srmr")

out.lin <- paste ("acti", "metric", round(acti.metric.cfi.sav, digits = 3), round(acti.metric.rmsea.sav, digits = 3), round(acti.metric.srmr.sav, digits = 3), sep = ",", collapse = NULL)
write(out.lin, file = "mi_study2.txt", append = TRUE)


#AESTHETICS
#configural model
aest.mod <- paste("
                  aest.lat =~ oopn06 + oopn09r + oopn10
                  ")

#aest.config.fit <- sem(aest.mod, data = dat, group = "cnt_now")
#aest.config.cfi.sav <- fitMeasures(aest.config.fit, "cfi")
#aest.config.rmsea.sav <- fitMeasures(aest.config.fit, "rmsea")
#aest.config.srmr.sav <- fitMeasures(aest.config.fit, "srmr")

#out.lin <- paste ("aest", "config", round(aest.config.cfi.sav, digits = 3), round(aest.config.rmsea.sav, digits = 3), round(aest.config.srmr.sav, digits = 3), sep = ",", collapse = NULL)
#write(out.lin, file = "mi_study2.txt", append = TRUE)


#metric model
aest.metric.fit <- sem(aest.mod, data = dat, group = "cnt_now", group.equal = c("loadings"))
aest.metric.cfi.sav <- fitMeasures(aest.metric.fit, "cfi")
aest.metric.rmsea.sav <- fitMeasures(aest.metric.fit, "rmsea")
aest.metric.srmr.sav <- fitMeasures(aest.metric.fit, "srmr")

out.lin <- paste ("aest", "metric", round(aest.metric.cfi.sav, digits = 3), round(aest.metric.rmsea.sav, digits = 3), round(aest.metric.srmr.sav, digits = 3), sep = ",", collapse = NULL)
write(out.lin, file = "mi_study2.txt", append = TRUE)


#IDEAS
#configural model
idea.mod <- paste("
                  idea.lat =~ oopn02 + oopn03 + oopn05 + oopn07r + oopn08
                  ")

idea.config.fit <- sem(idea.mod, data = dat, group = "cnt_now")
idea.config.cfi.sav <- fitMeasures(idea.config.fit, "cfi")
idea.config.rmsea.sav <- fitMeasures(idea.config.fit, "rmsea")
idea.config.srmr.sav <- fitMeasures(idea.config.fit, "srmr")

out.lin <- paste ("idea", "config", round(idea.config.cfi.sav, digits = 3), round(idea.config.rmsea.sav, digits = 3), round(idea.config.srmr.sav, digits = 3), sep = ",", collapse = NULL)
write(out.lin, file = "mi_study2.txt", append = TRUE)


#metric model
idea.metric.fit <- sem(idea.mod, data = dat, group = "cnt_now", group.equal = c("loadings"))
idea.metric.cfi.sav <- fitMeasures(idea.metric.fit, "cfi")
idea.metric.rmsea.sav <- fitMeasures(idea.metric.fit, "rmsea")
idea.metric.srmr.sav <- fitMeasures(idea.metric.fit, "srmr")

out.lin <- paste ("idea", "metric", round(idea.metric.cfi.sav, digits = 3), round(idea.metric.rmsea.sav, digits = 3), round(idea.metric.srmr.sav, digits = 3), sep = ",", collapse = NULL)
write(out.lin, file = "mi_study2.txt", append = TRUE)


#ANXIETY
#configural model
anxi.mod <- paste("
                  anxi.lat =~ oneu02r + oneu04 + oneu07r + oneu08
                  meth.fac =~ 1*oneu02r + 1*oneu07r 
                  anxi.lat ~~ 0*meth.fac
                  ")

anxi.config.fit <- sem(anxi.mod, data = dat, group = "cnt_now")
anxi.config.cfi.sav <- fitMeasures(anxi.config.fit, "cfi")
anxi.config.rmsea.sav <- fitMeasures(anxi.config.fit, "rmsea")
anxi.config.srmr.sav <- fitMeasures(anxi.config.fit, "srmr")

out.lin <- paste ("anxi", "config", round(anxi.config.cfi.sav, digits = 3), round(anxi.config.rmsea.sav, digits = 3), round(anxi.config.srmr.sav, digits = 3), sep = ",", collapse = NULL)
write(out.lin, file = "mi_study2.txt", append = TRUE)


#metric model
anxi.metric.fit <- sem(anxi.mod, data = dat, group = "cnt_now", group.equal = c("loadings"))
anxi.metric.cfi.sav <- fitMeasures(anxi.metric.fit, "cfi")
anxi.metric.rmsea.sav <- fitMeasures(anxi.metric.fit, "rmsea")
anxi.metric.srmr.sav <- fitMeasures(anxi.metric.fit, "srmr")

out.lin <- paste ("anxi", "metric", round(anxi.metric.cfi.sav, digits = 3), round(anxi.metric.rmsea.sav, digits = 3), round(anxi.metric.srmr.sav, digits = 3), sep = ",", collapse = NULL)
write(out.lin, file = "mi_study2.txt", append = TRUE)


#DEPRESSION
#configural model
depr.mod <- paste("
                  depr.lat =~ a*oneu01 + a*oneu06
                  depr.lat ~~ 1*depr.lat
                  ")

depr.config.fit <- sem(depr.mod, data = dat, group = "cnt_now")
depr.config.cfi.sav <- fitMeasures(depr.config.fit, "cfi")
depr.config.rmsea.sav <- fitMeasures(depr.config.fit, "rmsea")
depr.config.srmr.sav <- fitMeasures(depr.config.fit, "srmr")

out.lin <- paste ("depr", "config", round(depr.config.cfi.sav, digits = 3), round(depr.config.rmsea.sav, digits = 3), round(depr.config.srmr.sav, digits = 3), sep = ",", collapse = NULL)
write(out.lin, file = "mi_study2.txt", append = TRUE)


#metric model
depr.metric.fit <- sem(depr.mod, data = dat, group = "cnt_now", group.equal = c("loadings"))
depr.metric.cfi.sav <- fitMeasures(depr.metric.fit, "cfi")
depr.metric.rmsea.sav <- fitMeasures(depr.metric.fit, "rmsea")
depr.metric.srmr.sav <- fitMeasures(depr.metric.fit, "srmr")

out.lin <- paste ("depr", "metric", round(depr.metric.cfi.sav, digits = 3), round(depr.metric.rmsea.sav, digits = 3), round(depr.metric.srmr.sav, digits = 3), sep = ",", collapse = NULL)
write(out.lin, file = "mi_study2.txt", append = TRUE)

