#install packages
install.packages(c("foreign","psych","data.table"))

#load packages
library(foreign, pos=4)
library(psych)
library(data.table)

#read data
dat <- read.spss("http://madata.bib.uni-mannheim.de/333/1/B5FacetsRelig_Study2_data.sav", use.value.labels=FALSE, max.value.labels=inf, to.data.frame=TRUE)

#z-standardize criterion
dat$zoprel <- scale(dat$orelig)

#compute level-2 predictor (z-standardized on Level 2)
dat1 <- aggregate(orelig ~ cnt_now, dat, mean)        
dat1$zocrel <- scale(dat1$orelig)
dat1$orelig <- NULL
dat <- merge(dat, dat1, by = "cnt_now", all = TRUE)
rm(dat1)

#re-center level-2 predictor for simple slope analysis
dat$zocrelmax <- dat$zocrel - abs(max(dat$zocrel))
dat$zocrelmin <- dat$zocrel + abs(min(dat$zocrel))

#group-mean center and z-standardize level-1 predictors (informant-report)
##Big Five facets
dat$zoaltrgrp <- scale(dat$oaltr - ave(dat$oaltr, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zocompgrp <- scale(dat$ocomp - ave(dat$ocomp, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoordegrp <- scale(dat$oorde - ave(dat$oorde, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zodiscgrp <- scale(dat$odisc - ave(dat$odisc, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoactigrp <- scale(dat$oacti - ave(dat$oacti, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoassegrp <- scale(dat$oasse - ave(dat$oasse, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoaestgrp <- scale(dat$oaest - ave(dat$oaest, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoideagrp <- scale(dat$oidea - ave(dat$oidea, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoanxigrp <- scale(dat$oanxi - ave(dat$oanxi, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zodeprgrp <- scale(dat$odepr - ave(dat$odepr, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))

##Big Five nuances
dat$zoagr01rgrp <- scale(dat$oagr01r - ave(dat$oagr01r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoagr02grp <- scale(dat$oagr02 - ave(dat$oagr02, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoagr03rgrp <- scale(dat$oagr03r - ave(dat$oagr03r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoagr04grp <- scale(dat$oagr04 - ave(dat$oagr04, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoagr05grp <- scale(dat$oagr05 - ave(dat$oagr05, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoagr06rgrp <- scale(dat$oagr06r - ave(dat$oagr06r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoagr07grp <- scale(dat$oagr07 - ave(dat$oagr07, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zocns02rgrp <- scale(dat$ocns02r - ave(dat$ocns02r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zocns03grp <- scale(dat$ocns03 - ave(dat$ocns03, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zocns04rgrp <- scale(dat$ocns04r - ave(dat$ocns04r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zocns05rgrp <- scale(dat$ocns05r - ave(dat$ocns05r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zocns06grp <- scale(dat$ocns06 - ave(dat$ocns06, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zocns08grp <- scale(dat$ocns08 - ave(dat$ocns08, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zocns09rgrp <- scale(dat$ocns09r - ave(dat$ocns09r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoext01grp <- scale(dat$oext01 - ave(dat$oext01, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoext02rgrp <- scale(dat$oext02r - ave(dat$oext02r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoext03grp <- scale(dat$oext03 - ave(dat$oext03, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoext04grp <- scale(dat$oext04 - ave(dat$oext04, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoext05rgrp <- scale(dat$oext05r - ave(dat$oext05r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoext06grp <- scale(dat$oext06 - ave(dat$oext06, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoext07rgrp <- scale(dat$oext07r - ave(dat$oext07r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoneu01grp <- scale(dat$oneu01 - ave(dat$oneu01, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoneu02rgrp <- scale(dat$oneu02r - ave(dat$oneu02r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoneu04grp <- scale(dat$oneu04 - ave(dat$oneu04, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoneu06grp <- scale(dat$oneu06 - ave(dat$oneu06, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoneu07rgrp <- scale(dat$oneu07r - ave(dat$oneu07r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoneu08grp <- scale(dat$oneu08 - ave(dat$oneu08, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoopn02grp <- scale(dat$oopn02 - ave(dat$oopn02, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoopn03grp <- scale(dat$oopn03 - ave(dat$oopn03, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoopn05grp <- scale(dat$oopn05 - ave(dat$oopn05, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoopn06grp <- scale(dat$oopn06 - ave(dat$oopn06, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoopn07rgrp <- scale(dat$oopn07r - ave(dat$oopn07r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoopn08grp <- scale(dat$oopn08 - ave(dat$oopn08, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoopn09rgrp <- scale(dat$oopn09r - ave(dat$oopn09r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoopn10grp <- scale(dat$oopn10 - ave(dat$oopn10, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))

##Big Five facets without one specific Big Five nuance
dat$zoaltr_no_oagr02grp <- scale(dat$oaltr_no_oagr02 - ave(dat$oaltr_no_oagr02, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoaltr_no_oagr05grp <- scale(dat$oaltr_no_oagr05 - ave(dat$oaltr_no_oagr05, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoaltr_no_oagr06rgrp <- scale(dat$oaltr_no_oagr06r - ave(dat$oaltr_no_oagr06r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoaltr_no_oagr07grp <- scale(dat$oaltr_no_oagr07 - ave(dat$oaltr_no_oagr07, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zocomp_no_oagr01rgrp <- scale(dat$ocomp_no_oagr01r - ave(dat$ocomp_no_oagr01r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zocomp_no_oagr03rgrp <- scale(dat$ocomp_no_oagr03r - ave(dat$ocomp_no_oagr03r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zocomp_no_oagr04grp <- scale(dat$ocomp_no_oagr04 - ave(dat$ocomp_no_oagr04, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zodisc_no_ocns03grp <- scale(dat$odisc_no_ocns03 - ave(dat$odisc_no_ocns03, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zodisc_no_ocns05rgrp <- scale(dat$odisc_no_ocns05r - ave(dat$odisc_no_ocns05r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zodisc_no_ocns06grp <- scale(dat$odisc_no_ocns06 - ave(dat$odisc_no_ocns06, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zodisc_no_ocns08grp <- scale(dat$odisc_no_ocns08 - ave(dat$odisc_no_ocns08, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zodisc_no_ocns09rgrp <- scale(dat$odisc_no_ocns09r - ave(dat$odisc_no_ocns09r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoasse_no_oext01grp <- scale(dat$oasse_no_oext01 - ave(dat$oasse_no_oext01, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoasse_no_oext02rgrp <- scale(dat$oasse_no_oext02r - ave(dat$oasse_no_oext02r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoasse_no_oext05rgrp <- scale(dat$oasse_no_oext05r - ave(dat$oasse_no_oext05r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoasse_no_oext06grp <- scale(dat$oasse_no_oext06 - ave(dat$oasse_no_oext06, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoasse_no_oext07rgrp <- scale(dat$oasse_no_oext07r - ave(dat$oasse_no_oext07r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoaest_no_oopn06grp <- scale(dat$oaest_no_oopn06 - ave(dat$oaest_no_oopn06, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoaest_no_oopn09rgrp <- scale(dat$oaest_no_oopn09r - ave(dat$oaest_no_oopn09r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoaest_no_oopn10grp <- scale(dat$oaest_no_oopn10 - ave(dat$oaest_no_oopn10, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoidea_no_oopn02grp <- scale(dat$oidea_no_oopn02 - ave(dat$oidea_no_oopn02, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoidea_no_oopn03grp <- scale(dat$oidea_no_oopn03 - ave(dat$oidea_no_oopn03, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoidea_no_oopn05grp <- scale(dat$oidea_no_oopn05 - ave(dat$oidea_no_oopn05, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoidea_no_oopn07r <- scale(dat$oidea_no_oopn07r - ave(dat$oidea_no_oopn07r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoidea_no_oopn08grp <- scale(dat$oidea_no_oopn08 - ave(dat$oidea_no_oopn08, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoanxi_no_oneu02rgrp <- scale(dat$oanxi_no_oneu02r - ave(dat$oanxi_no_oneu02r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoanxi_no_oneu04grp <- scale(dat$oanxi_no_oneu04 - ave(dat$oanxi_no_oneu04, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoanxi_no_oneu07rgrp <- scale(dat$oanxi_no_oneu07r - ave(dat$oanxi_no_oneu07r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zoanxi_no_oneu08grp <- scale(dat$oanxi_no_oneu08 - ave(dat$oanxi_no_oneu08, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))

#group-mean center and z-standardize covariates (self-report)
##personal religiosity
dat$zprelgrp <- scale(dat$relig - ave(dat$relig, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))

##Big Five facets
dat$zaltrgrp <- scale(dat$altr - ave(dat$altr, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zcompgrp <- scale(dat$comp - ave(dat$comp, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zordegrp <- scale(dat$orde - ave(dat$orde, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zdiscgrp <- scale(dat$disc - ave(dat$disc, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zactigrp <- scale(dat$acti - ave(dat$acti, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zassegrp <- scale(dat$asse - ave(dat$asse, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zaestgrp <- scale(dat$aest - ave(dat$aest, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zideagrp <- scale(dat$idea - ave(dat$idea, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zanxigrp <- scale(dat$anxi - ave(dat$anxi, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zdeprgrp <- scale(dat$depr - ave(dat$depr, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))

##Big Five nuances
dat$zagr01rgrp <- scale(dat$agr01r - ave(dat$agr01r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zagr02grp <- scale(dat$agr02 - ave(dat$agr02, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zagr03rgrp <- scale(dat$agr03r - ave(dat$agr03r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zagr04grp <- scale(dat$agr04 - ave(dat$agr04, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zagr05grp <- scale(dat$agr05 - ave(dat$agr05, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zagr06rgrp <- scale(dat$agr06r - ave(dat$agr06r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zagr07grp <- scale(dat$agr07 - ave(dat$agr07, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zcns02rgrp <- scale(dat$cns02r - ave(dat$cns02r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zcns03grp <- scale(dat$cns03 - ave(dat$cns03, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zcns04rgrp <- scale(dat$cns04r - ave(dat$cns04r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zcns05rgrp <- scale(dat$cns05r - ave(dat$cns05r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zcns06grp <- scale(dat$cns06 - ave(dat$cns06, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zcns08grp <- scale(dat$cns08 - ave(dat$cns08, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zcns09rgrp <- scale(dat$cns09r - ave(dat$cns09r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zext01grp <- scale(dat$ext01 - ave(dat$ext01, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zext02rgrp <- scale(dat$ext02r - ave(dat$ext02r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zext03grp <- scale(dat$ext03 - ave(dat$ext03, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zext04grp <- scale(dat$ext04 - ave(dat$ext04, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zext05rgrp <- scale(dat$ext05r - ave(dat$ext05r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zext06grp <- scale(dat$ext06 - ave(dat$ext06, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zext07rgrp <- scale(dat$ext07r - ave(dat$ext07r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zneu01grp <- scale(dat$neu01 - ave(dat$neu01, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zneu02rgrp <- scale(dat$neu02r - ave(dat$neu02r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zneu04grp <- scale(dat$neu04 - ave(dat$neu04, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zneu06grp <- scale(dat$neu06 - ave(dat$neu06, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zneu07rgrp <- scale(dat$neu07r - ave(dat$neu07r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zneu08grp <- scale(dat$neu08 - ave(dat$neu08, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zopn02grp <- scale(dat$opn02 - ave(dat$opn02, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zopn03grp <- scale(dat$opn03 - ave(dat$opn03, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zopn05grp <- scale(dat$opn05 - ave(dat$opn05, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zopn06grp <- scale(dat$opn06 - ave(dat$opn06, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zopn07rgrp <- scale(dat$opn07r - ave(dat$opn07r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zopn08grp <- scale(dat$opn08 - ave(dat$opn08, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zopn09rgrp <- scale(dat$opn09r - ave(dat$opn09r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zopn10grp <- scale(dat$opn10 - ave(dat$opn10, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))

##Big Five facets without one specific Big Five nuance
dat$zaltr_no_agr02grp <- scale(dat$altr_no_agr02 - ave(dat$altr_no_agr02, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zaltr_no_agr05grp <- scale(dat$altr_no_agr05 - ave(dat$altr_no_agr05, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zaltr_no_agr06rgrp <- scale(dat$altr_no_agr06r - ave(dat$altr_no_agr06r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zaltr_no_agr07grp <- scale(dat$altr_no_agr07 - ave(dat$altr_no_agr07, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zcomp_no_agr01rgrp <- scale(dat$comp_no_agr01r - ave(dat$comp_no_agr01r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zcomp_no_agr03rgrp <- scale(dat$comp_no_agr03r - ave(dat$comp_no_agr03r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zcomp_no_agr04grp <- scale(dat$comp_no_agr04 - ave(dat$comp_no_agr04, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zdisc_no_cns03grp <- scale(dat$disc_no_cns03 - ave(dat$disc_no_cns03, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zdisc_no_cns05rgrp <- scale(dat$disc_no_cns05r - ave(dat$disc_no_cns05r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zdisc_no_cns06grp <- scale(dat$disc_no_cns06 - ave(dat$disc_no_cns06, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zdisc_no_cns08grp <- scale(dat$disc_no_cns08 - ave(dat$disc_no_cns08, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zdisc_no_cns09rgrp <- scale(dat$disc_no_cns09r - ave(dat$disc_no_cns09r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zasse_no_ext01grp <- scale(dat$asse_no_ext01 - ave(dat$asse_no_ext01, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zasse_no_ext02rgrp <- scale(dat$asse_no_ext02r - ave(dat$asse_no_ext02r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zasse_no_ext05rgrp <- scale(dat$asse_no_ext05r - ave(dat$asse_no_ext05r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zasse_no_ext06grp <- scale(dat$asse_no_ext06 - ave(dat$asse_no_ext06, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zasse_no_ext07rgrp <- scale(dat$asse_no_ext07r - ave(dat$asse_no_ext07r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zaest_no_opn06grp <- scale(dat$aest_no_opn06 - ave(dat$aest_no_opn06, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zaest_no_opn09rgrp <- scale(dat$aest_no_opn09r - ave(dat$aest_no_opn09r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zaest_no_opn10grp <- scale(dat$aest_no_opn10 - ave(dat$aest_no_opn10, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zidea_no_opn02grp <- scale(dat$idea_no_opn02 - ave(dat$idea_no_opn02, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zidea_no_opn03grp <- scale(dat$idea_no_opn03 - ave(dat$idea_no_opn03, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zidea_no_opn05grp <- scale(dat$idea_no_opn05 - ave(dat$idea_no_opn05, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zidea_no_opn07r <- scale(dat$idea_no_opn07r - ave(dat$idea_no_opn07r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zidea_no_opn08grp <- scale(dat$idea_no_opn08 - ave(dat$idea_no_opn08, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zanxi_no_neu02rgrp <- scale(dat$anxi_no_neu02r - ave(dat$anxi_no_neu02r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zanxi_no_neu04grp <- scale(dat$anxi_no_neu04 - ave(dat$anxi_no_neu04, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zanxi_no_neu07rgrp <- scale(dat$anxi_no_neu07r - ave(dat$anxi_no_neu07r, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))
dat$zanxi_no_neu08grp <- scale(dat$anxi_no_neu08 - ave(dat$anxi_no_neu08, dat$cnt_now, FUN = function(x) mean(x, na.rm=T)))

#select variables for facet model in Julia
dat1 <- subset(dat, select = c(record_id,cnt_now,zocrel,zocrelmax,zocrelmin,zoprel,zoaltrgrp:zodeprgrp,zprelgrp:zdeprgrp))

#select variables for nuance model in Julia
dat2 <- subset(dat, select = c(record_id,cnt_now,zocrel,zocrelmax,zocrelmin,zoprel,zoagr01rgrp:zoopn10grp,zprelgrp,zagr01rgrp:zopn10grp))

#select variables and save data for indirect-effects analyses in Mplus
##select variables
dat3 <- subset(dat, select = c(record_id,cnt_now,zoprel,zocrel,zoaltrgrp:zanxi_no_neu08grp))
####set working directory to the folder to which the dataset should be saved (e.g., "C:/B5FacetsRelig") and save data
setwd("C:/B5FacetsRelig")
fwrite(dat3, file = "B5FacetsRelig_Study2_mplus-data.csv", col.names = FALSE)

rm(dat,dat3)


#####Before you continue with this R-Syntax, download and install Julia (https://julialang.org/downloads/)#####


#install JuliaCall
install.packages("JuliaCall")

#load JuliaCall
library(JuliaCall)

#start Julia
julia <- julia_setup() 

#set working directory to the Julia folder indicated in julia_setup (e.g., "C:/AppData/Local/JULIA-~1.1/bin")
setwd("C:/AppData/Local/JULIA-~1.1/bin")

#install Julia packages
julia_install_package("MixedModels")
julia_install_package("DataFrames")
julia_install_package("StatsBase")

#load Julia packages
julia_library("MixedModels")
julia_library("DataFrames")
julia_library("StatsBase")

#conduct facet model in Julia
dat1$cnt_now <- as.factor(dat1$cnt_now)
julia_assign("dat1", dat1)

julia_eval("fm1 = fit(LinearMixedModel, @formula(zoprel ~ 1 + zprelgrp + zoaltrgrp * zocrel + zocompgrp * zocrel + zoordegrp * zocrel + zodiscgrp * zocrel + zoassegrp * zocrel
+ zoactigrp * zocrel + zoideagrp * zocrel + zoaestgrp * zocrel + zodeprgrp * zocrel + zoanxigrp * zocrel
+ zaltrgrp * zocrel + zcompgrp * zocrel + zordegrp * zocrel + zdiscgrp * zocrel + zassegrp * zocrel
+ zactigrp * zocrel + zideagrp * zocrel + zaestgrp * zocrel + zdeprgrp * zocrel + zanxigrp * zocrel
+ (1 | cnt_now) + ((0 + zprelgrp) | cnt_now) + ((0 + zoaltrgrp) | cnt_now) + ((0 + zocompgrp) | cnt_now)
+ ((0 + zoordegrp) | cnt_now) + ((0 + zodiscgrp) | cnt_now)
+ ((0 + zoassegrp) | cnt_now) + ((0 + zoactigrp) | cnt_now)
+ ((0 + zoideagrp) | cnt_now) + ((0 + zoaestgrp) | cnt_now)
+ ((0 + zodeprgrp) | cnt_now) + ((0 + zoanxigrp) | cnt_now)
+ ((0 + zaltrgrp) | cnt_now) + ((0 + zcompgrp) | cnt_now)
+ ((0 + zordegrp) | cnt_now) + ((0 + zdiscgrp) | cnt_now)
+ ((0 + zassegrp) | cnt_now) + ((0 + zactigrp) | cnt_now)
+ ((0 + zideagrp) | cnt_now) + ((0 + zaestgrp) | cnt_now)
+ ((0 + zdeprgrp) | cnt_now) + ((0 + zanxigrp) | cnt_now)), dat1)")
results_study2_facets <- julia_eval("results_study2_facets = rename!(DataFrame([(coeftable(fm1).rownms) (round.(fixef(fm1, false),digits=5)) (round.(((fixef(fm1, false))-1.96*(stderror(fm1))),digits=5)) (round.(((fixef(fm1, false))+1.96*(stderror(fm1))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

##most religious countries
julia_eval("fm1a = fit(LinearMixedModel, @formula(zoprel ~ 1 + zprelgrp + zoaltrgrp * zocrelmax + zocompgrp * zocrelmax + zoordegrp * zocrelmax + zodiscgrp * zocrelmax + zoassegrp * zocrelmax
+ zoactigrp * zocrelmax + zoideagrp * zocrelmax + zoaestgrp * zocrelmax + zodeprgrp * zocrelmax + zoanxigrp * zocrelmax
+ zaltrgrp * zocrelmax + zcompgrp * zocrelmax + zordegrp * zocrelmax + zdiscgrp * zocrelmax + zassegrp * zocrelmax
+ zactigrp * zocrelmax + zideagrp * zocrelmax + zaestgrp * zocrelmax + zdeprgrp * zocrelmax + zanxigrp * zocrelmax
+ (1 | cnt_now) + ((0 + zprelgrp) | cnt_now) + ((0 + zoaltrgrp) | cnt_now) + ((0 + zocompgrp) | cnt_now)
+ ((0 + zoordegrp) | cnt_now) + ((0 + zodiscgrp) | cnt_now)
+ ((0 + zoassegrp) | cnt_now) + ((0 + zoactigrp) | cnt_now)
+ ((0 + zoideagrp) | cnt_now) + ((0 + zoaestgrp) | cnt_now)
+ ((0 + zodeprgrp) | cnt_now) + ((0 + zoanxigrp) | cnt_now)
+ ((0 + zaltrgrp) | cnt_now) + ((0 + zcompgrp) | cnt_now)
+ ((0 + zordegrp) | cnt_now) + ((0 + zdiscgrp) | cnt_now)
+ ((0 + zassegrp) | cnt_now) + ((0 + zactigrp) | cnt_now)
+ ((0 + zideagrp) | cnt_now) + ((0 + zaestgrp) | cnt_now)
+ ((0 + zdeprgrp) | cnt_now) + ((0 + zanxigrp) | cnt_now)), dat1)")
results_study2_facets_cmax <- julia_eval("results_study2_facets_cmax = rename!(DataFrame([(coeftable(fm1a).rownms) (round.(fixef(fm1a, false),digits=5)) (round.(((fixef(fm1a, false))-1.96*(stderror(fm1a))),digits=5)) (round.(((fixef(fm1a, false))+1.96*(stderror(fm1a))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

##least religious countries
julia_eval("fm1b = fit(LinearMixedModel, @formula(zoprel ~ 1 + zprelgrp + zoaltrgrp * zocrelmin + zocompgrp * zocrelmin + zoordegrp * zocrelmin + zodiscgrp * zocrelmin + zoassegrp * zocrelmin
+ zoactigrp * zocrelmin + zoideagrp * zocrelmin + zoaestgrp * zocrelmin + zodeprgrp * zocrelmin + zoanxigrp * zocrelmin
+ zaltrgrp * zocrelmin + zcompgrp * zocrelmin + zordegrp * zocrelmin + zdiscgrp * zocrelmin + zassegrp * zocrelmin
+ zactigrp * zocrelmin + zideagrp * zocrelmin + zaestgrp * zocrelmin + zdeprgrp * zocrelmin + zanxigrp * zocrelmin
+ (1 | cnt_now) + ((0 + zprelgrp) | cnt_now) + ((0 + zoaltrgrp) | cnt_now) + ((0 + zocompgrp) | cnt_now)
+ ((0 + zoordegrp) | cnt_now) + ((0 + zodiscgrp) | cnt_now)
+ ((0 + zoassegrp) | cnt_now) + ((0 + zoactigrp) | cnt_now)
+ ((0 + zoideagrp) | cnt_now) + ((0 + zoaestgrp) | cnt_now)
+ ((0 + zodeprgrp) | cnt_now) + ((0 + zoanxigrp) | cnt_now)
+ ((0 + zaltrgrp) | cnt_now) + ((0 + zcompgrp) | cnt_now)
+ ((0 + zordegrp) | cnt_now) + ((0 + zdiscgrp) | cnt_now)
+ ((0 + zassegrp) | cnt_now) + ((0 + zactigrp) | cnt_now)
+ ((0 + zideagrp) | cnt_now) + ((0 + zaestgrp) | cnt_now)
+ ((0 + zdeprgrp) | cnt_now) + ((0 + zanxigrp) | cnt_now)), dat1)")
results_study2_facets_cmin <- julia_eval("results_study2_facets_cmin = rename!(DataFrame([(coeftable(fm1b).rownms) (round.(fixef(fm1b, false),digits=5)) (round.(((fixef(fm1b, false))-1.96*(stderror(fm1b))),digits=5)) (round.(((fixef(fm1b, false))+1.96*(stderror(fm1b))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")


#conduct nuance model in Julia
dat2$cnt_now <- as.factor(dat2$cnt_now)
julia_assign("dat2", dat2)

julia_eval("fm2 = fit(LinearMixedModel, @formula(zoprel ~ 1 + zprelgrp + zoagr02grp * zocrel + zoagr05grp * zocrel + zoagr06rgrp * zocrel + zoagr07grp * zocrel 
+ zoagr01rgrp * zocrel + zoagr03rgrp * zocrel + zoagr04grp * zocrel
+ zocns02rgrp * zocrel + zocns04rgrp * zocrel + zocns03grp * zocrel + zocns05rgrp * zocrel + zocns06grp * zocrel + zocns08grp * zocrel + zocns09rgrp * zocrel
+ zoext01grp * zocrel + zoext02rgrp * zocrel + zoext05rgrp * zocrel + zoext06grp * zocrel + zoext07rgrp * zocrel + zoext03grp * zocrel + zoext04grp * zocrel
+ zoopn02grp * zocrel + zoopn03grp * zocrel + zoopn05grp * zocrel + zoopn07rgrp * zocrel + zoopn08grp * zocrel + zoopn06grp * zocrel + zoopn09rgrp * zocrel + zoopn10grp * zocrel
+ zoneu01grp * zocrel + zoneu06grp * zocrel + zoneu02rgrp * zocrel + zoneu04grp * zocrel + zoneu07rgrp * zocrel + zoneu08grp * zocrel
+ zagr02grp * zocrel + zagr05grp * zocrel + zagr06rgrp * zocrel + zagr07grp * zocrel + zagr01rgrp * zocrel + zagr03rgrp * zocrel + zagr04grp * zocrel
+ zcns02rgrp * zocrel + zcns04rgrp * zocrel + zcns03grp * zocrel + zcns05rgrp * zocrel + zcns06grp * zocrel + zcns08grp * zocrel + zcns09rgrp * zocrel
+ zext01grp * zocrel + zext02rgrp * zocrel + zext05rgrp * zocrel + zext06grp * zocrel + zext07rgrp * zocrel + zext03grp * zocrel + zext04grp * zocrel
+ zopn02grp * zocrel + zopn03grp * zocrel + zopn05grp * zocrel + zopn07rgrp * zocrel + zopn08grp * zocrel + zopn06grp * zocrel + zopn09rgrp * zocrel + zopn10grp * zocrel
+ zneu01grp * zocrel + zneu06grp * zocrel + zneu02rgrp * zocrel + zneu04grp * zocrel + zneu07rgrp * zocrel + zneu08grp * zocrel
+ (1 | cnt_now) + ((0 + zoagr02grp) | cnt_now) + ((0 + zoagr05grp) | cnt_now) + ((0 + zoagr06rgrp) | cnt_now) + ((0 + zoagr07grp) | cnt_now) 
+ ((0 + zoagr01rgrp) | cnt_now) + ((0 + zoagr03rgrp) | cnt_now) + ((0 + zoagr04grp) | cnt_now)
+ ((0 + zocns02rgrp) | cnt_now) + ((0 + zocns04rgrp) | cnt_now) + ((0 + zocns03grp) | cnt_now) + ((0 + zocns05rgrp) | cnt_now) 
+ ((0 + zocns06grp) | cnt_now) + ((0 + zocns08grp) | cnt_now) + ((0 + zocns09rgrp) | cnt_now) 
+ ((0 + zoext01grp) | cnt_now) + ((0 + zoext02rgrp) | cnt_now) + ((0 + zoext05rgrp) | cnt_now) + ((0 + zoext06grp) | cnt_now) + ((0 + zoext07rgrp) | cnt_now)
+ ((0 + zoext03grp) | cnt_now) + ((0 + zoext04grp) | cnt_now)
+ ((0 + zoopn02grp) | cnt_now) + ((0 + zoopn03grp) | cnt_now) + ((0 + zoopn05grp) | cnt_now) + ((0 + zoopn07rgrp) | cnt_now) + ((0 + zoopn08grp) | cnt_now)
+ ((0 + zoopn06grp) | cnt_now) + ((0 + zoopn09rgrp) | cnt_now) + ((0 + zoopn10grp) | cnt_now)
+ ((0 + zoneu01grp) | cnt_now) + ((0 + zoneu06grp) | cnt_now) 
+ ((0 + zoneu02rgrp) | cnt_now) + ((0 + zoneu04grp) | cnt_now) + ((0 + zoneu07rgrp) | cnt_now) + ((0 + zoneu08grp) | cnt_now)), dat2)")
results_study2_nuances <- julia_eval("results_study2_nuances = rename!(DataFrame([(coeftable(fm2).rownms) (round.(fixef(fm2, false),digits=5)) (round.(((fixef(fm2, false))-1.96*(stderror(fm2))),digits=5)) (round.(((fixef(fm2, false))+1.96*(stderror(fm2))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

##most religious countries
julia_eval("fm2a = fit(LinearMixedModel, @formula(zoprel ~ 1 + zprelgrp + zoagr02grp * zocrelmax + zoagr05grp * zocrelmax + zoagr06rgrp * zocrelmax + zoagr07grp * zocrelmax 
+ zoagr01rgrp * zocrelmax + zoagr03rgrp * zocrelmax + zoagr04grp * zocrelmax
+ zocns02rgrp * zocrelmax + zocns04rgrp * zocrelmax + zocns03grp * zocrelmax + zocns05rgrp * zocrelmax + zocns06grp * zocrelmax + zocns08grp * zocrelmax + zocns09rgrp * zocrelmax
+ zoext01grp * zocrelmax + zoext02rgrp * zocrelmax + zoext05rgrp * zocrelmax + zoext06grp * zocrelmax + zoext07rgrp * zocrelmax + zoext03grp * zocrelmax + zoext04grp * zocrelmax
+ zoopn02grp * zocrelmax + zoopn03grp * zocrelmax + zoopn05grp * zocrelmax + zoopn07rgrp * zocrelmax + zoopn08grp * zocrelmax + zoopn06grp * zocrelmax + zoopn09rgrp * zocrelmax + zoopn10grp * zocrelmax
+ zoneu01grp * zocrelmax + zoneu06grp * zocrelmax + zoneu02rgrp * zocrelmax + zoneu04grp * zocrelmax + zoneu07rgrp * zocrelmax + zoneu08grp * zocrelmax
+ zagr02grp * zocrelmax + zagr05grp * zocrelmax + zagr06rgrp * zocrelmax + zagr07grp * zocrelmax + zagr01rgrp * zocrelmax + zagr03rgrp * zocrelmax + zagr04grp * zocrelmax
+ zcns02rgrp * zocrelmax + zcns04rgrp * zocrelmax + zcns03grp * zocrelmax + zcns05rgrp * zocrelmax + zcns06grp * zocrelmax + zcns08grp * zocrelmax + zcns09rgrp * zocrelmax
+ zext01grp * zocrelmax + zext02rgrp * zocrelmax + zext05rgrp * zocrelmax + zext06grp * zocrelmax + zext07rgrp * zocrelmax + zext03grp * zocrelmax + zext04grp * zocrelmax
+ zopn02grp * zocrelmax + zopn03grp * zocrelmax + zopn05grp * zocrelmax + zopn07rgrp * zocrelmax + zopn08grp * zocrelmax + zopn06grp * zocrelmax + zopn09rgrp * zocrelmax + zopn10grp * zocrelmax
+ zneu01grp * zocrelmax + zneu06grp * zocrelmax + zneu02rgrp * zocrelmax + zneu04grp * zocrelmax + zneu07rgrp * zocrelmax + zneu08grp * zocrelmax
+ (1 | cnt_now) + ((0 + zoagr02grp) | cnt_now) + ((0 + zoagr05grp) | cnt_now) + ((0 + zoagr06rgrp) | cnt_now) + ((0 + zoagr07grp) | cnt_now) 
+ ((0 + zoagr01rgrp) | cnt_now) + ((0 + zoagr03rgrp) | cnt_now) + ((0 + zoagr04grp) | cnt_now)
+ ((0 + zocns02rgrp) | cnt_now) + ((0 + zocns04rgrp) | cnt_now) + ((0 + zocns03grp) | cnt_now) + ((0 + zocns05rgrp) | cnt_now) 
+ ((0 + zocns06grp) | cnt_now) + ((0 + zocns08grp) | cnt_now) + ((0 + zocns09rgrp) | cnt_now) 
+ ((0 + zoext01grp) | cnt_now) + ((0 + zoext02rgrp) | cnt_now) + ((0 + zoext05rgrp) | cnt_now) + ((0 + zoext06grp) | cnt_now) + ((0 + zoext07rgrp) | cnt_now)
+ ((0 + zoext03grp) | cnt_now) + ((0 + zoext04grp) | cnt_now)
+ ((0 + zoopn02grp) | cnt_now) + ((0 + zoopn03grp) | cnt_now) + ((0 + zoopn05grp) | cnt_now) + ((0 + zoopn07rgrp) | cnt_now) + ((0 + zoopn08grp) | cnt_now)
+ ((0 + zoopn06grp) | cnt_now) + ((0 + zoopn09rgrp) | cnt_now) + ((0 + zoopn10grp) | cnt_now)
+ ((0 + zoneu01grp) | cnt_now) + ((0 + zoneu06grp) | cnt_now) 
+ ((0 + zoneu02rgrp) | cnt_now) + ((0 + zoneu04grp) | cnt_now) + ((0 + zoneu07rgrp) | cnt_now) + ((0 + zoneu08grp) | cnt_now)), dat2)")
results_study2_nuances_cmax <- julia_eval("results_study2_nuances_cmax = rename!(DataFrame([(coeftable(fm2a).rownms) (round.(fixef(fm2a, false),digits=5)) (round.(((fixef(fm2a, false))-1.96*(stderror(fm2a))),digits=5)) (round.(((fixef(fm2a, false))+1.96*(stderror(fm2a))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

##least religious countries
julia_eval("fm2b = fit(LinearMixedModel, @formula(zoprel ~ 1 + zprelgrp + zoagr02grp * zocrelmin + zoagr05grp * zocrelmin + zoagr06rgrp * zocrelmin + zoagr07grp * zocrelmin 
+ zoagr01rgrp * zocrelmin + zoagr03rgrp * zocrelmin + zoagr04grp * zocrelmin
+ zocns02rgrp * zocrelmin + zocns04rgrp * zocrelmin + zocns03grp * zocrelmin + zocns05rgrp * zocrelmin + zocns06grp * zocrelmin + zocns08grp * zocrelmin + zocns09rgrp * zocrelmin
+ zoext01grp * zocrelmin + zoext02rgrp * zocrelmin + zoext05rgrp * zocrelmin + zoext06grp * zocrelmin + zoext07rgrp * zocrelmin + zoext03grp * zocrelmin + zoext04grp * zocrelmin
+ zoopn02grp * zocrelmin + zoopn03grp * zocrelmin + zoopn05grp * zocrelmin + zoopn07rgrp * zocrelmin + zoopn08grp * zocrelmin + zoopn06grp * zocrelmin + zoopn09rgrp * zocrelmin + zoopn10grp * zocrelmin
+ zoneu01grp * zocrelmin + zoneu06grp * zocrelmin + zoneu02rgrp * zocrelmin + zoneu04grp * zocrelmin + zoneu07rgrp * zocrelmin + zoneu08grp * zocrelmin
+ zagr02grp * zocrelmin + zagr05grp * zocrelmin + zagr06rgrp * zocrelmin + zagr07grp * zocrelmin + zagr01rgrp * zocrelmin + zagr03rgrp * zocrelmin + zagr04grp * zocrelmin
+ zcns02rgrp * zocrelmin + zcns04rgrp * zocrelmin + zcns03grp * zocrelmin + zcns05rgrp * zocrelmin + zcns06grp * zocrelmin + zcns08grp * zocrelmin + zcns09rgrp * zocrelmin
+ zext01grp * zocrelmin + zext02rgrp * zocrelmin + zext05rgrp * zocrelmin + zext06grp * zocrelmin + zext07rgrp * zocrelmin + zext03grp * zocrelmin + zext04grp * zocrelmin
+ zopn02grp * zocrelmin + zopn03grp * zocrelmin + zopn05grp * zocrelmin + zopn07rgrp * zocrelmin + zopn08grp * zocrelmin + zopn06grp * zocrelmin + zopn09rgrp * zocrelmin + zopn10grp * zocrelmin
+ zneu01grp * zocrelmin + zneu06grp * zocrelmin + zneu02rgrp * zocrelmin + zneu04grp * zocrelmin + zneu07rgrp * zocrelmin + zneu08grp * zocrelmin
+ (1 | cnt_now) + ((0 + zoagr02grp) | cnt_now) + ((0 + zoagr05grp) | cnt_now) + ((0 + zoagr06rgrp) | cnt_now) + ((0 + zoagr07grp) | cnt_now) 
+ ((0 + zoagr01rgrp) | cnt_now) + ((0 + zoagr03rgrp) | cnt_now) + ((0 + zoagr04grp) | cnt_now)
+ ((0 + zocns02rgrp) | cnt_now) + ((0 + zocns04rgrp) | cnt_now) + ((0 + zocns03grp) | cnt_now) + ((0 + zocns05rgrp) | cnt_now) 
+ ((0 + zocns06grp) | cnt_now) + ((0 + zocns08grp) | cnt_now) + ((0 + zocns09rgrp) | cnt_now) 
+ ((0 + zoext01grp) | cnt_now) + ((0 + zoext02rgrp) | cnt_now) + ((0 + zoext05rgrp) | cnt_now) + ((0 + zoext06grp) | cnt_now) + ((0 + zoext07rgrp) | cnt_now)
+ ((0 + zoext03grp) | cnt_now) + ((0 + zoext04grp) | cnt_now)
+ ((0 + zoopn02grp) | cnt_now) + ((0 + zoopn03grp) | cnt_now) + ((0 + zoopn05grp) | cnt_now) + ((0 + zoopn07rgrp) | cnt_now) + ((0 + zoopn08grp) | cnt_now)
+ ((0 + zoopn06grp) | cnt_now) + ((0 + zoopn09rgrp) | cnt_now) + ((0 + zoopn10grp) | cnt_now)
+ ((0 + zoneu01grp) | cnt_now) + ((0 + zoneu06grp) | cnt_now) 
+ ((0 + zoneu02rgrp) | cnt_now) + ((0 + zoneu04grp) | cnt_now) + ((0 + zoneu07rgrp) | cnt_now) + ((0 + zoneu08grp) | cnt_now)), dat2)")
results_study2_nuances_cmin <- julia_eval("results_study2_nuances_cmin = rename!(DataFrame([(coeftable(fm2b).rownms) (round.(fixef(fm2b, false),digits=5)) (round.(((fixef(fm2b, false))-1.96*(stderror(fm2b))),digits=5)) (round.(((fixef(fm2b, false))+1.96*(stderror(fm2b))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")
